@@ -9,6 +9,7 @@ no if $] >= 5.018, warnings => "experimental::smartmatch";
 use Carp qw(cluck);
 use Encode qw(decode encode);
 use Travel::Routing::DE::EFA::Route;
+use Travel::Routing::DE::EFA::Route::Message;
 use LWP::UserAgent;
 use XML::LibXML;
 
@@ -31,7 +32,7 @@ use Exception::Class (
 	'Travel::Routing::DE::EFA::Exception::Ambiguous' => {
 		isa         => 'Travel::Routing::DE::EFA::Exception',
 		description => 'ambiguous input',
-		fields      => [ 'post_key', 'possibilities' ],
+		fields      => [ 'post_key', 'post_value', 'possibilities' ],
 	},
 	'Travel::Routing::DE::EFA::Exception::Other' => {
 		isa         => 'Travel::Routing::DE::EFA::Exception',
@@ -40,7 +41,7 @@ use Exception::Class (
 	},
 );
 
-our $VERSION = '2.08';
+our $VERSION = '2.13';
 
 sub set_time {
 	my ( $self, %conf ) = @_;
@@ -203,9 +204,16 @@ sub train_type {
 }
 
 sub use_near_stops {
-	my ( $self, $toggle ) = @_;
+	my ( $self, $duration ) = @_;
 
-	$self->{post}->{useProxFootSearch} = $toggle;
+	if ($duration) {
+		$self->{post}->{useProxFootSearch}  = 1;
+		$self->{post}->{trITArrMOTvalue100} = $duration;
+		$self->{post}->{trITDepMOTvalue100} = $duration;
+	}
+	else {
+		$self->{post}->{useProxFootSearch} = 0;
+	}
 
 	return;
 }
@@ -235,6 +243,46 @@ sub with_bike {
 	return;
 }
 
+sub without_solid_stairs {
+	my ( $self, $opt ) = @_;
+
+	$self->{post}->{noSolidStairs} = $opt;
+
+	return;
+}
+
+sub without_escalators {
+	my ( $self, $opt ) = @_;
+
+	$self->{post}->{noEscalators} = $opt;
+
+	return;
+}
+
+sub without_elevators {
+	my ( $self, $opt ) = @_;
+
+	$self->{post}->{noElevators} = $opt;
+
+	return;
+}
+
+sub with_low_platform {
+	my ( $self, $opt ) = @_;
+
+	$self->{post}->{lowPlatformVhcl} = $opt;
+
+	return;
+}
+
+sub with_wheelchair {
+	my ( $self, $opt ) = @_;
+
+	$self->{post}->{wheelchair} = $opt;
+
+	return;
+}
+
 sub place {
 	my ( $self, $which, $place, $stop, $type ) = @_;
 
@@ -245,9 +293,6 @@ sub place {
 		);
 	}
 
-	$place = encode( 'ISO-8859-15', $place );
-	$stop  = encode( 'ISO-8859-15', $stop );
-
 	$type //= 'stop';
 
 	@{ $self->{post} }{ "place_${which}", "name_${which}" } = ( $place, $stop );
@@ -266,93 +311,75 @@ sub create_post {
 	my @now  = localtime( time() );
 
 	$self->{post} = {
-		changeSpeed                                        => 'normal',
-		command                                            => q{},
-		execInst                                           => q{},
-		imparedOptionsActive                               => 1,
-		inclMOT_0                                          => 'on',
-		inclMOT_1                                          => 'on',
-		inclMOT_10                                         => 'on',
-		inclMOT_11                                         => 'on',
-		inclMOT_2                                          => 'on',
-		inclMOT_3                                          => 'on',
-		inclMOT_4                                          => 'on',
-		inclMOT_5                                          => 'on',
-		inclMOT_6                                          => 'on',
-		inclMOT_7                                          => 'on',
-		inclMOT_8                                          => 'on',
-		inclMOT_9                                          => 'on',
-		includedMeans                                      => 'checkbox',
-		itOptionsActive                                    => 1,
-		itdDateDay                                         => $now[3],
-		itdDateMonth                                       => $now[4] + 1,
-		itdDateYear                                        => $now[5] + 1900,
-		itdLPxx_ShowFare                                   => q{ },
-		itdLPxx_command                                    => q{},
-		itdLPxx_enableMobilityRestrictionOptionsWithButton => q{},
-		itdLPxx_id_destination                             => ':destination',
-		itdLPxx_id_origin                                  => ':origin',
-		itdLPxx_id_via                                     => ':via',
-		itdLPxx_mapState_destination                       => q{},
-		itdLPxx_mapState_origin                            => q{},
-		itdLPxx_mapState_via                               => q{},
-		itdLPxx_mdvMap2_destination                        => q{},
-		itdLPxx_mdvMap2_origin                             => q{},
-		itdLPxx_mdvMap2_via                                => q{},
-		itdLPxx_mdvMap_destination                         => q{::},
-		itdLPxx_mdvMap_origin                              => q{::},
-		itdLPxx_mdvMap_via                                 => q{::},
-		itdLPxx_priceCalculator                            => q{},
-		itdLPxx_transpCompany                              => 'vrr',
-		itdLPxx_view                                       => q{},
-		itdTimeHour                                        => $now[2],
-		itdTimeMinute                                      => $now[1],
-		itdTripDateTimeDepArr                              => 'dep',
-		language                                           => 'de',
-		lineRestriction                                    => 403,
-		maxChanges                                         => 9,
-		nameInfo_destination                               => 'invalid',
-		nameInfo_origin                                    => 'invalid',
-		nameInfo_via                                       => 'invalid',
-		nameState_destination                              => 'empty',
-		nameState_origin                                   => 'empty',
-		nameState_via                                      => 'empty',
-		name_destination                                   => q{},
-		name_origin                                        => q{},
-		name_via                                           => q{},
-		nextDepsPerLeg                                     => 1,
-		outputFormat                                       => 'XML',
-		placeInfo_destination                              => 'invalid',
-		placeInfo_origin                                   => 'invalid',
-		placeInfo_via                                      => 'invalid',
-		placeState_destination                             => 'empty',
-		placeState_origin                                  => 'empty',
-		placeState_via                                     => 'empty',
-		place_destination                                  => q{},
-		place_origin                                       => q{},
-		place_via                                          => q{},
-		ptOptionsActive                                    => 1,
-		requestID                                          => 0,
-		routeType                                          => 'LEASTTIME',
-		sessionID                                          => 0,
-		text                                               => 1993,
-		trITArrMOT                                         => 100,
-		trITArrMOTvalue100                                 => 8,
-		trITArrMOTvalue101                                 => 10,
-		trITArrMOTvalue104                                 => 10,
-		trITArrMOTvalue105                                 => 10,
-		trITDepMOT                                         => 100,
-		trITDepMOTvalue100                                 => 8,
-		trITDepMOTvalue101                                 => 10,
-		trITDepMOTvalue104                                 => 10,
-		trITDepMOTvalue105                                 => 10,
-		typeInfo_destination                               => 'invalid',
-		typeInfo_origin                                    => 'invalid',
-		typeInfo_via                                       => 'invalid',
-		type_destination                                   => 'stop',
-		type_origin                                        => 'stop',
-		type_via                                           => 'stop',
-		useRealtime                                        => 1
+		changeSpeed            => 'normal',
+		command                => q{},
+		execInst               => q{},
+		imparedOptionsActive   => 1,
+		inclMOT_0              => 'on',
+		inclMOT_1              => 'on',
+		inclMOT_10             => 'on',
+		inclMOT_11             => 'on',
+		inclMOT_2              => 'on',
+		inclMOT_3              => 'on',
+		inclMOT_4              => 'on',
+		inclMOT_5              => 'on',
+		inclMOT_6              => 'on',
+		inclMOT_7              => 'on',
+		inclMOT_8              => 'on',
+		inclMOT_9              => 'on',
+		includedMeans          => 'checkbox',
+		itOptionsActive        => 1,
+		itdDateDay             => $now[3],
+		itdDateMonth           => $now[4] + 1,
+		itdDateYear            => $now[5] + 1900,
+		itdTimeHour            => $now[2],
+		itdTimeMinute          => $now[1],
+		itdTripDateTimeDepArr  => 'dep',
+		language               => 'de',
+		lineRestriction        => 403,
+		maxChanges             => 9,
+		nameInfo_destination   => 'invalid',
+		nameInfo_origin        => 'invalid',
+		nameInfo_via           => 'invalid',
+		nameState_destination  => 'empty',
+		nameState_origin       => 'empty',
+		nameState_via          => 'empty',
+		name_destination       => q{},
+		name_origin            => q{},
+		name_via               => q{},
+		nextDepsPerLeg         => 1,
+		outputFormat           => 'XML',
+		placeInfo_destination  => 'invalid',
+		placeInfo_origin       => 'invalid',
+		placeInfo_via          => 'invalid',
+		placeState_destination => 'empty',
+		placeState_origin      => 'empty',
+		placeState_via         => 'empty',
+		place_destination      => q{},
+		place_origin           => q{},
+		place_via              => q{},
+		ptOptionsActive        => 1,
+		requestID              => 0,
+		routeType              => 'LEASTTIME',
+		sessionID              => 0,
+		text                   => 1993,
+		trITArrMOT             => 100,
+		trITArrMOTvalue100     => 10,
+		trITArrMOTvalue101     => 10,
+		trITArrMOTvalue104     => 10,
+		trITArrMOTvalue105     => 10,
+		trITDepMOT             => 100,
+		trITDepMOTvalue100     => 10,
+		trITDepMOTvalue101     => 10,
+		trITDepMOTvalue104     => 10,
+		trITDepMOTvalue105     => 10,
+		typeInfo_destination   => 'invalid',
+		typeInfo_origin        => 'invalid',
+		typeInfo_via           => 'invalid',
+		type_destination       => 'stop',
+		type_origin            => 'stop',
+		type_via               => 'stop',
+		useRealtime            => 1
 	};
 
 	$self->place( 'origin',      @{ $conf->{origin} } );
@@ -380,7 +407,7 @@ sub create_post {
 		$self->select_interchange_by( $conf->{select_interchange_by} );
 	}
 	if ( $conf->{use_near_stops} ) {
-		$self->use_near_stops(1);
+		$self->use_near_stops( $conf->{use_near_stops} );
 	}
 	if ( $conf->{train_type} ) {
 		$self->train_type( $conf->{train_type} );
@@ -391,6 +418,25 @@ sub create_post {
 	if ( $conf->{with_bike} ) {
 		$self->with_bike(1);
 	}
+	if ( $conf->{with_low_platform} ) {
+		$self->with_low_platform(1);
+	}
+	if ( $conf->{with_wheelchair} ) {
+		$self->with_wheelchair(1);
+	}
+	if ( $conf->{without_solid_stairs} ) {
+		$self->without_solid_stairs(1);
+	}
+	if ( $conf->{without_escalators} ) {
+		$self->without_escalators(1);
+	}
+	if ( $conf->{without_elevators} ) {
+		$self->without_elevators(1);
+	}
+
+	for my $val ( values %{ $self->{post} } ) {
+		$val = encode( 'ISO-8859-15', $val );
+	}
 
 	return;
 }
@@ -489,6 +535,42 @@ sub itdtime_str {
 		$node->getAttribute('minute') );
 }
 
+sub parse_cur_info {
+	my ( $self, $node ) = @_;
+
+	my $xp_text     = XML::LibXML::XPathExpression->new('./infoLinkText');
+	my $xp_subject  = XML::LibXML::XPathExpression->new('./infoText/subject');
+	my $xp_subtitle = XML::LibXML::XPathExpression->new('./infoText/subtitle');
+	my $xp_content  = XML::LibXML::XPathExpression->new('./infoText/content');
+
+	my $e_text     = ( $node->findnodes($xp_text) )[0];
+	my $e_subject  = ( $node->findnodes($xp_subject) )[0];
+	my $e_subtitle = ( $node->findnodes($xp_subtitle) )[0];
+	my $e_content  = ( $node->findnodes($xp_content) )[0];
+
+	my %msg = (
+		summary     => $e_text->textContent,
+		subject     => $e_subject->textContent,
+		subtitle    => $e_subtitle->textContent,
+		raw_content => $e_content->textContent,
+	);
+	for my $key ( keys %msg ) {
+		$msg{$key} = decode( 'UTF-8', $msg{$key} );
+		chomp( $msg{$key} );
+	}
+	return Travel::Routing::DE::EFA::Route::Message->new(%msg);
+}
+
+sub parse_reg_info {
+	my ( $self, $node ) = @_;
+
+	my %msg = (
+		summary => decode( 'UTF-8', $node->textContent ),
+	);
+
+	return Travel::Routing::DE::EFA::Route::Message->new(%msg);
+}
+
 sub parse_xml_part {
 	my ( $self, $route ) = @_;
 
@@ -506,10 +588,15 @@ sub parse_xml_part {
 	  = XML::LibXML::XPathExpression->new('./itdDateTimeTarget/itdDate');
 	my $xp_stime
 	  = XML::LibXML::XPathExpression->new('./itdDateTimeTarget/itdTime');
-	my $xp_mot   = XML::LibXML::XPathExpression->new('./itdMeansOfTransport');
+	my $xp_mot = XML::LibXML::XPathExpression->new('./itdMeansOfTransport');
+	my $xp_fp  = XML::LibXML::XPathExpression->new('./itdFootPathInfo');
+	my $xp_fp_e
+	  = XML::LibXML::XPathExpression->new('./itdFootPathInfo/itdFootPathElem');
 	my $xp_delay = XML::LibXML::XPathExpression->new('./itdRBLControlled');
-	my $xp_info
+
+	my $xp_sched_info
 	  = XML::LibXML::XPathExpression->new('./itdInfoTextList/infoTextListElem');
+	my $xp_cur_info = XML::LibXML::XPathExpression->new('./infoLink');
 
 	my $xp_mapitem_rm = XML::LibXML::XPathExpression->new(
 		'./itdMapItemList/itdMapItem[@type="RM"]/itdImage');
@@ -549,11 +636,14 @@ sub parse_xml_part {
 		my $e_astime  = ( $e_arr->findnodes($xp_stime) )[0];
 		my $e_mot     = ( $e->findnodes($xp_mot) )[0];
 		my $e_delay   = ( $e->findnodes($xp_delay) )[0];
-		my @e_info    = $e->findnodes($xp_info);
+		my $e_fp      = ( $e->findnodes($xp_fp) )[0];
+		my @e_sinfo   = $e->findnodes($xp_sched_info);
+		my @e_cinfo   = $e->findnodes($xp_cur_info);
 		my @e_dmap_rm = $e_dep->findnodes($xp_mapitem_rm);
 		my @e_dmap_sm = $e_dep->findnodes($xp_mapitem_sm);
 		my @e_amap_rm = $e_arr->findnodes($xp_mapitem_rm);
 		my @e_amap_sm = $e_arr->findnodes($xp_mapitem_sm);
+		my @e_fp_e    = $e->findnodes($xp_fp_e);
 
 		# not all EFA services distinguish between scheduled and realtime
 		# data. Set sdate / stime to date / time when not provided.
@@ -586,6 +676,7 @@ sub parse_xml_part {
 			departure_stop     => $e_dep->getAttribute('name'),
 			departure_platform => $e_dep->getAttribute('platformName'),
 			train_line         => $e_mot->getAttribute('name'),
+			train_product      => $e_mot->getAttribute('productName'),
 			train_destination  => $e_mot->getAttribute('destination'),
 			arrival_date       => $self->itddate_str($e_adate),
 			arrival_time       => $self->itdtime_str($e_atime),
@@ -599,6 +690,22 @@ sub parse_xml_part {
 			$hash->{$key} = decode( 'UTF-8', $hash->{$key} );
 		}
 
+		if ($e_fp) {
+
+			# Note that position=IDEST footpaths are coupled with a special
+			# "walking" connection, so their duration is already known and
+			# accounted for. However, we still save it here, since
+			# detecting and handling this is the API client's job (for now).
+			$hash->{footpath_type}     = $e_fp->getAttribute('position');
+			$hash->{footpath_duration} = $e_fp->getAttribute('duration');
+			for my $e (@e_fp_e) {
+				push(
+					@{ $hash->{footpath_parts} },
+					[ $e->getAttribute('type'), $e->getAttribute('level') ]
+				);
+			}
+		}
+
 		$hash->{departure_routemaps}   = \@dep_rms;
 		$hash->{departure_stationmaps} = \@dep_sms;
 		$hash->{arrival_routemaps}     = \@arr_rms;
@@ -632,7 +739,9 @@ sub parse_xml_part {
 			);
 		}
 
-		$hash->{extra} = [ map { decode( 'UTF-8', $_->textContent ) } @e_info ];
+		$hash->{regular_notes}
+		  = [ map { $self->parse_reg_info($_) } @e_sinfo ];
+		$hash->{current_notes} = [ map { $self->parse_cur_info($_) } @e_cinfo ];
 
 		push( @route_parts, $hash );
 	}
@@ -652,7 +761,9 @@ sub parse_xml {
 		string => $self->{xml_reply},
 	);
 
-	#say $tree->toString(2);
+	if ( $self->{config}->{developer_mode} ) {
+		say $tree->toString(2);
+	}
 
 	my $xp_element = XML::LibXML::XPathExpression->new(
 		'//itdItinerary/itdRouteList/itdRoute');
@@ -687,8 +798,10 @@ sub check_ambiguous_xml {
 	my $xp_place = XML::LibXML::XPathExpression->new('./itdOdvPlace');
 	my $xp_name  = XML::LibXML::XPathExpression->new('./itdOdvName');
 
-	my $xp_place_elem = XML::LibXML::XPathExpression->new('./odvPlaceElem');
-	my $xp_name_elem  = XML::LibXML::XPathExpression->new('./odvNameElem');
+	my $xp_place_elem  = XML::LibXML::XPathExpression->new('./odvPlaceElem');
+	my $xp_place_input = XML::LibXML::XPathExpression->new('./odvPlaceInput');
+	my $xp_name_elem   = XML::LibXML::XPathExpression->new('./odvNameElem');
+	my $xp_name_input  = XML::LibXML::XPathExpression->new('./odvNameInput');
 
 	my $e_place = ( $tree->findnodes($xp_place) )[0];
 	my $e_name  = ( $tree->findnodes($xp_name) )[0];
@@ -703,7 +816,11 @@ sub check_ambiguous_xml {
 
 	if ( $s_place eq 'list' ) {
 		Travel::Routing::DE::EFA::Exception::Ambiguous->throw(
-			post_key      => 'place',
+			post_key   => 'place',
+			post_value => decode(
+				'UTF-8',
+				( $e_place->findnodes($xp_place_input) )[0]->textContent
+			),
 			possibilities => join( q{ | },
 				map { decode( 'UTF-8', $_->textContent ) }
 				  @{ $e_place->findnodes($xp_place_elem) } )
@@ -711,7 +828,10 @@ sub check_ambiguous_xml {
 	}
 	if ( $s_name eq 'list' ) {
 		Travel::Routing::DE::EFA::Exception::Ambiguous->throw(
-			post_key      => 'name',
+			post_key   => 'name',
+			post_value => decode(
+				'UTF-8', ( $e_name->findnodes($xp_name_input) )[0]->textContent
+			),
 			possibilities => join( q{ | },
 				map { decode( 'UTF-8', $_->textContent ) }
 				  @{ $e_name->findnodes($xp_name_elem) } )
@@ -745,9 +865,14 @@ sub routes {
 # static
 sub get_efa_urls {
 	return (
+		{
+			url       => 'http://www.ding.eu/ding3/XSLT_TRIP_REQUEST2',
+			name      => 'Donau-Iller Nahverkehrsverbund',
+			shortname => 'DING',
+		},
 		{
 			url       => 'http://efa.ivb.at/ivb/XSLT_TRIP_REQUEST2',
-			name      => 'Innsbrucker Verkehsbetriebe',
+			name      => 'Innsbrucker Verkehrsbetriebe',
 			shortname => 'IVB',
 		},
 		{
@@ -767,7 +892,7 @@ sub get_efa_urls {
 		},
 		{
 			url  => 'http://fahrplan.verbundlinie.at/stv/XSLT_TRIP_REQUEST2',
-			name => 'Verkehsverbund Steiermark',
+			name => 'Verkehrsverbund Steiermark',
 			shortname => 'Verbundlinie',
 		},
 		{
@@ -785,6 +910,11 @@ sub get_efa_urls {
 			name      => 'Verkehrsverbund Rhein-Ruhr',
 			shortname => 'VRR',
 		},
+		{
+			url       => 'http://app.vrr.de/standard/XML_TRIP_REQUEST2',
+			name      => 'Verkehrsverbund Rhein-Ruhr (alternative)',
+			shortname => 'VRR2',
+		},
 		{
 			url       => 'http://www2.vvs.de/vvs/XSLT_TRIP_REQUEST2',
 			name      => 'Verkehrsverbund Stuttgart',
@@ -825,7 +955,7 @@ Travel::Routing::DE::EFA - unofficial interface to EFA-based itinerary services
 
 =head1 VERSION
 
-version 2.08
+version 2.13
 
 =head1 DESCRIPTION
 
@@ -861,7 +991,7 @@ is not completely supported yet and may not work at all.
 
 =over
 
-=item * L<http://efa.ivb.at/ivb/XSLT_TRIP_REQUEST2> (Innsbrucker Verkehsbetriebe)
+=item * L<http://efa.ivb.at/ivb/XSLT_TRIP_REQUEST2> (Innsbrucker Verkehrsbetriebe)
 
 =item * L<http://efa.svv-info.at/sbs/XSLT_TRIP_REQUEST2> (Salzburger Verkehrsverbund)
 
@@ -869,7 +999,7 @@ is not completely supported yet and may not work at all.
 
 =item * L<http://efaneu.vmobil.at/vvv/XSLT_TRIP_REQUEST2> (Vorarlberger Verkehrsverbund)
 
-=item * L<http://fahrplan.verbundlinie.at/stv/XSLT_TRIP_REQUEST2> (Verkehsverbund Steiermark) B<[!]>
+=item * L<http://fahrplan.verbundlinie.at/stv/XSLT_TRIP_REQUEST2> (Verkehrsverbund Steiermark) B<[!]>
 
 =item * L<http://www.linzag.at/static/XSLT_TRIP_REQUEST2> (Linz AG) B<[!]>
 
@@ -883,6 +1013,8 @@ is not completely supported yet and may not work at all.
 
 =item * L<http://efa.vrr.de/vrr/XSLT_TRIP_REQUEST2> (Verkehrsverbund Rhein-Ruhr)
 
+=item * L<http://app.vrr.de/standard/XML_TRIP_REQUEST2> (Verkehrsverbund Rhein-Ruhr with support for B<--full-route>)
+
 =item * L<http://www2.vvs.de/vvs/XSLT_TRIP_REQUEST2> (Verkehrsverbund Stuttgart)
 
 =back
@@ -939,13 +1071,17 @@ EFA server is used (usually 4 or 5).
 Prefer either fast connections (default), connections with low wait time or
 connections with little distance to walk
 
-=item B<use_near_stops> => B<0>|B<1>
+=item B<use_near_stops> => I<$int>
 
-If true: Try using near stops instead of the specified origin/destination ones
+If I<$int> is a true value: Take stops close to the stop/start into account and
+possibly use them instead. Up to I<$int> minutes of walking are considered
+acceptable.
+
+Otherwise: Do not take stops close to stop/start into account.
 
 =item B<train_type> => B<local>|B<ic>|B<ice>
 
-Include only local trains into itinarery (default), all but ICEs, or all.
+Include only local trains into itinerary (default), all but ICEs, or all.
 
 The latter two are usually way more expensive for short routes.
 
@@ -955,7 +1091,34 @@ Set walk speed.  Default: B<normal>
 
 =item B<with_bike> => B<0>|B<1>
 
-If true: Prefer connections allowing passengers with bikes
+If true: Request connections allowing passengers with bikes. Note that the
+backed may return an empty result if no such connection exists or bike-support
+simply isn't known.
+
+=item B<with_low_platform> => B<0>|B<1>
+
+If true: Request connections which only use low-platform ("Niederflur")
+vehicles. Note that the backed will return an empty result if no such
+connection exists.
+
+=item B<with_wheelchair> => B<0>|B<1>
+
+If true: Request connections which are wheelchair-accessible. Again, note that
+the backend may return an empty result if no such connection exists or
+wheelchair-support isn't known.
+
+=item B<without_elevators> => B<0>|B<1>
+
+If true: Request that transfers do not require usage of elevators.
+
+=item B<without_escalators> => B<0>|B<1>
+
+If true: Request that transfers do not require usage of escalators.
+
+=item B<without_solid_stairs> => B<0>|B<1>
+
+If true: Request that transfers do not require stairs to be taken (i.e.
+ramps, escalators, elevators or similar must be available).
 
 =item B<lwp_options> => I<\%hashref>
 
@@ -1000,7 +1163,7 @@ The following methods act like the arguments to B<new>. See there.
 
 =item $efa->train_type(I<$type>)
 
-=item $efa->use_near_stops(I<$bool>)
+=item $efa->use_near_stops(I<$duration>)
 
 =item $efa->walk_speed(I<$speed>)
 
@@ -1062,7 +1225,7 @@ None known.
 
 =head1 AUTHOR
 
-Copyright (C) 2009-2014 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2009-2015 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
